@@ -1,7 +1,8 @@
 labbcat.url <- "https://labbcat.canterbury.ac.nz/demo"
-labbcatCredentials(labbcat.url, "demo", "demo")
 
 test_that("getParticipantIds works", {
+    if (!is.null(labbcatCredentials(labbcat.url, "demo", "demo"))) skip("Server not available")
+
     ids <- getParticipantIds(labbcat.url)
     expect_true(length(ids) >= 41)
     expect_true("QB247_Jacqui" %in% ids)
